diff --git a/UPGRADE-1.8.txt b/UPGRADE-1.8.txt
index 230a5ef4019600b01213bb53b066236741f27b0e..75efabe7f5f22d16af429a19d8a1a3813b5c540e 100644
--- a/UPGRADE-1.8.txt
+++ b/UPGRADE-1.8.txt
@@ -311,3 +311,6 @@ From 1.6.0.x to 1.6.1:
   which should be a char(8) or larger.  This field specifies whether or not a
   message has been designated to be "Urgent", "PRIORITY", or not.
 
+* The 'sipusers' realtime table has been removed completely. Use the 'sippeers'
+  table with type 'user' for user type objects.
+
diff --git a/configs/dbsep.conf.sample b/configs/dbsep.conf.sample
index 9e0dd04e0eb76ed44a566cc5ae56f3fed13fb22a..9cfa2374077ae2aba738471e636f7addcdb3039e 100644
--- a/configs/dbsep.conf.sample
+++ b/configs/dbsep.conf.sample
@@ -17,8 +17,7 @@
 # and res_config_curl.so in modules.conf and configure extconfig.conf:
 #
 # voicemail => curl,http://server/path/to/dbsep.cgi/voicemail
-# sippeers => curl,http://server/path/to/dbsep.cgi/sipfriends
-# sipusers => curl,http://server/path/to/dbsep.cgi/sipfriends
+# sippeers => curl,http://server/path/to/dbsep.cgi/sippeers
 #
 
 # The Data Source Name, as specified by the Perl DBI module.
diff --git a/configs/extconfig.conf.sample b/configs/extconfig.conf.sample
index cc3fa9c9f2911c44cf414247008ed52040008bdc..e08674e9d94e379d8add196368819721234c9392 100644
--- a/configs/extconfig.conf.sample
+++ b/configs/extconfig.conf.sample
@@ -63,7 +63,6 @@
 ;
 ;iaxusers => odbc,asterisk
 ;iaxpeers => odbc,asterisk
-;sipusers => odbc,asterisk
 ;sippeers => odbc,asterisk
 ;sipregs => odbc,asterisk
 ;voicemail => odbc,asterisk
diff --git a/configs/res_config_mysql.conf.sample b/configs/res_config_mysql.conf.sample
index 79eaf97d2699e5563b92ca7b24df976edaebd71b..ab8ebf095095a3f50c4703eccaebd03f0619ef70 100644
--- a/configs/res_config_mysql.conf.sample
+++ b/configs/res_config_mysql.conf.sample
@@ -17,7 +17,7 @@
 ; and writes should be performed to the same database.
 ;
 ; For example, in extconfig.conf, you could specify a line like:
-;    sippeers => mysql,readhost.asterisk/writehost.asterisk,sipfriends
+;    sippeers => mysql,readhost.asterisk/writehost.asterisk,sippeers
 ; and then define the contexts [readhost.asterisk] and [writehost.asterisk]
 ; below.
 ;
diff --git a/configs/res_ldap.conf.sample b/configs/res_ldap.conf.sample
index c49fbf1c3c227bc635f34408f4a858d6143f4889..4655841ec6afff4e9a7b5dfcdeb84915ed9d2a5e 100644
--- a/configs/res_ldap.conf.sample
+++ b/configs/res_ldap.conf.sample
@@ -7,7 +7,6 @@
 ; In order to use this module, you start 
 ; in extconfig.conf with a configuration like this:
 ;
-; 	sipusers = ldap,"dc=myDomain,dc=myDomainExt",sip
 ; 	sippeers = ldap,"dc=myDomain,dc=myDomainExt",sip
 ; 	extensions = ldap,"dc=myDomain,dc=myDomainExt",extensions
 ; 	sip.conf = ldap,"dc=myDomain,dc=myDomainExt",config
diff --git a/main/config.c b/main/config.c
index 6381a53f578ef10d1e1af83765cb3f4a975ee2f4..23d98da8afe8de76260fdf746543d09fc5a61971 100644
--- a/main/config.c
+++ b/main/config.c
@@ -2146,8 +2146,7 @@ int read_config_maps(void)
 		if (!driver || !database)
 			continue;
 		if (!strcasecmp(v->name, "sipfriends")) {
-			ast_log(LOG_WARNING, "The 'sipfriends' table is obsolete, update your config to use sipusers and sippeers, though they can point to the same table.\n");
-			append_mapping("sipusers", driver, database, table ? table : "sipfriends", pri);
+			ast_log(LOG_WARNING, "The 'sipfriends' table is obsolete, update your config to use sippeers instead.\n");
 			append_mapping("sippeers", driver, database, table ? table : "sipfriends", pri);
 		} else if (!strcasecmp(v->name, "iaxfriends")) {
 			ast_log(LOG_WARNING, "The 'iaxfriends' table is obsolete, update your config to use iaxusers and iaxpeers, though they can point to the same table.\n");
diff --git a/res/res_realtime.c b/res/res_realtime.c
index 8b1488fe489f39e8ae35377a611de266c54ca0ca..b26cde5b3469ce858e7473638add5d95dca7a9f0 100644
--- a/res/res_realtime.c
+++ b/res/res_realtime.c
@@ -93,8 +93,8 @@ static char *cli_realtime_update(struct ast_cli_entry *e, int cmd, struct ast_cl
 			"Usage: realtime update <family> <colmatch> <valuematch> <colupdate> <newvalue>\n"
 			"       Update a single variable using the RealTime driver.\n"
 			"       You must supply a family name, a column to update on, a new value, column to match, and value to match.\n"
-			"       Ex: realtime update sipfriends name bobsphone port 4343\n"
-			"       will execute SQL as UPDATE sipfriends SET port = 4343 WHERE name = bobsphone\n";
+			"       Ex: realtime update sippeers name bobsphone port 4343\n"
+			"       will execute SQL as UPDATE sippeers SET port = 4343 WHERE name = bobsphone\n";
 		return NULL;
 	case CLI_GENERATE:
 		return NULL;
@@ -127,9 +127,9 @@ static char *cli_realtime_update2(struct ast_cli_entry *e, int cmd, struct ast_c
 			"   Update a single variable, requiring one or more fields to match using the\n"
 			"   RealTime driver.  You must supply a family name, a column to update, a new\n"
 			"   value, and at least one column and value to match.\n"
-			"   Ex: realtime update sipfriends name bobsphone ipaddr 127.0.0.1 NULL port 4343\n"
+			"   Ex: realtime update sippeers name bobsphone ipaddr 127.0.0.1 NULL port 4343\n"
 			"   will execute SQL as\n"
-			"   UPDATE sipfriends SET port='4343' WHERE name='bobsphone' and ipaddr='127.0.0.1'\n";
+			"   UPDATE sippeers SET port='4343' WHERE name='bobsphone' and ipaddr='127.0.0.1'\n";
 		return NULL;
 	case CLI_GENERATE:
 		return NULL;
diff --git a/contrib/realtime/mysql/sipfriends.sql b/contrib/realtime/mysql/sippeers.sql
similarity index 96%
rename from contrib/realtime/mysql/sipfriends.sql
rename to contrib/realtime/mysql/sippeers.sql
index 07cd8788aaa5cf8da6b4f914830cd39c60d06d81..2393dd47636b1d070f0e0f17949a4493c420052a 100644
--- a/contrib/realtime/mysql/sipfriends.sql
+++ b/contrib/realtime/mysql/sippeers.sql
@@ -1,8 +1,8 @@
 #
 # Table structure for table `sipfriends`
 #
 
-CREATE TABLE IF NOT EXISTS `sipfriends` (
+CREATE TABLE IF NOT EXISTS `sippeers` (
       `id` int(11) NOT NULL AUTO_INCREMENT,
       `name` varchar(10) NOT NULL,
       `ipaddr` varchar(15) DEFAULT NULL,
@@ -28,7 +28,8 @@ CREATE TABLE IF NOT EXISTS `sipfriends` (
       `callgroup` varchar(40) DEFAULT NULL,
       `pickupgroup` varchar(40) DEFAULT NULL,
       `language` varchar(40) DEFAULT NULL,
-      `allow` varchar(200) DEFAULT NULL,
+      `allow` varchar(40) DEFAULT NULL,
+      `disallow` varchar(40) DEFAULT NULL,
       `insecure` varchar(40) DEFAULT NULL,
       `trustrpid` enum('yes','no') DEFAULT NULL,
       `progressinband` enum('yes','no','never') DEFAULT NULL,
@@ -1,8 +1,8 @@
 #
-# Table structure for table `sipfriends`
+# Table structure for table `sippeers`
 #
 